pub trait NodeTimeExt<T: Timeline> {
// Required methods
fn create_time<'a>(
&self,
name: impl Into<Cow<'a, str>>,
) -> CreateTimeResult<T>;
fn create_time_at<'a>(
&self,
name: impl Into<Cow<'a, str>>,
timestamp: Instant<T>,
) -> TimeProperty<T>;
fn record_time<'a>(&self, name: impl Into<Cow<'a, str>>) -> Instant<T>;
}Expand description
Extension trait that allows to manage timestamp properties.
Required Methods
Sourcefn create_time<'a>(&self, name: impl Into<Cow<'a, str>>) -> CreateTimeResult<T>
fn create_time<'a>(&self, name: impl Into<Cow<'a, str>>) -> CreateTimeResult<T>
Creates a new property holding the current timestamp on the given timeline. Returns the current timestamp that was used for the returned property too.
Sourcefn create_time_at<'a>(
&self,
name: impl Into<Cow<'a, str>>,
timestamp: Instant<T>,
) -> TimeProperty<T>
fn create_time_at<'a>( &self, name: impl Into<Cow<'a, str>>, timestamp: Instant<T>, ) -> TimeProperty<T>
Creates a new property holding the given timestamp.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".