pub struct DedupeLogNode<T: Unit + PartialEq> { /* private fields */ }Expand description
A Inspect node that holds an ordered, bounded list of log entries, with the ability to dedupe consecutive logs.
Implementations
Sourceimpl<T: Unit + PartialEq> DedupeLogNode<T>
impl<T: Unit + PartialEq> DedupeLogNode<T>
pub fn new(node: Node, capacity: usize) -> Self
Sourcepub fn insert(&mut self, log: T)
pub fn insert(&mut self, log: T)
Insert |log| into DedupeLogNode.
If |log| is equivalent to the last inserted log, the last inserted log entry’s count is incremented and last seen time is updated. If the new log is not equivalent to the last inserted log, a new log entry is inserted, and the oldest log entry is removed if capacity is exceeded.